"""
xkings: eine kleine Library mit deinem Druck-Kürzel hs und dem süssen navex.
"""

__version__ = "0.1.2"  # Denk dran, Version hochzusetzen!

from .core import hs, navex

__all__ = ["hs", "navex"]
